/*
 * Flipdot Demo serial control
 * Copyright (C) 2013  B. Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <QtGui>

#include "fdbox.h"

#define ANIDELAY	10

fdbox::fdbox(int _chon, int _choff)
{
	setMinimumWidth(50);
	setMinimumHeight(50);
	onoff = 0;
	anistate = 0;
	chon = _chon;
	choff = _choff;
	timer = new QTimer(this);
	connect(timer, SIGNAL(timeout()), this, SLOT(update()));
	timer->start(ANIDELAY);
}

void fdbox::resizeEvent(QResizeEvent *e)
{
	if(e->size().width() > e->size().height())
		resize(e->size().height(), e->size().height());
	if(e->size().width() < e->size().height())
		resize(e->size().width(), e->size().width());
}

void fdbox::paintEvent(QPaintEvent *)
{
	QPainter p(this);
	QPoint mid(width()/2, height()/2);
	QPoint sft(width()/2+1, -height()/4+1);
	QPoint a[5] = { QPoint(2, 2), QPoint(2, 8), QPoint(4, 8), QPoint(8, 4), QPoint(8, 2) };
	QPoint b[5] = { QPoint(width()-2, height()-2), QPoint(width()-2, height()-8), QPoint(width()-4, height()-8), QPoint(width()-8, height()-4), QPoint(width()-8, height()-2) };

	p.setBrush(QBrush(Qt::black));
	p.setPen(QPen(Qt::black, 1));
	p.drawConvexPolygon(a, 5);
	p.drawConvexPolygon(b, 5);
	p.drawLine(2, 2, width()-2, height()-2);

	switch(anistate) {
	case -3:
		p.setBrush(QBrush(Qt::black));
		p.setPen(QPen(Qt::black, 1));
		p.drawEllipse(mid, width()/2-2, height()/2-2);
		if(!onoff) timer->stop();
		break;
	case -2:
		p.setBrush(QBrush(Qt::black));
		p.setPen(QPen(Qt::black, 1));
		p.translate(sft);
		p.rotate(45.0);
		p.drawEllipse(QPoint(width()/2, height()/2), width()/2-2, height()*2/6);
		break;
	case -1:
		p.setBrush(QBrush(Qt::black));
		p.setPen(QPen(Qt::black, 1));
		p.translate(sft);
		p.rotate(45.0);
		p.drawEllipse(mid, width()/2-2, height()/6);
		break;
	case 0:
		p.setPen(QPen(Qt::black, 2));
		p.drawLine(3, 3, width()-3, height()-3);
		break;
	case 1:
		p.setBrush(QBrush(Qt::white));
		p.setPen(QPen(Qt::black, 1));
		p.translate(sft);
		p.rotate(45.0);
		p.drawEllipse(mid, width()/2-2, height()/6);
		break;
	case 2:
		p.setBrush(QBrush(Qt::white));
		p.setPen(QPen(Qt::black, 1));
		p.translate(sft);
		p.rotate(45.0);
		p.drawEllipse(mid, width()/2-2, height()*2/6);
		break;
	case 3:
		p.setBrush(QBrush(Qt::white));
		p.setPen(QPen(Qt::black, 1));
		p.drawEllipse(mid, width()/2-2, height()/2-2);
		if(onoff) timer->stop();
		break;
	}
	if(anistate < 3 && onoff)
		anistate++;
	if(anistate > -3 && !onoff)
		anistate--;
}

void fdbox::mousePressEvent(QMouseEvent *e)
{
	if(e->button() & Qt::LeftButton) {
		setstate(!onoff);
		emit changed(onoff ? chon : choff);
	}
}

void fdbox::setstate(int x)
{
	if((onoff && x) || (!onoff && !x))
		return;
	onoff = !!x;
	timer->start(ANIDELAY);
	update();
}
