/*
 * Flipdot Demo serial control
 * Copyright (C) 2013  B. Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <QtGui>
#include <QSocketNotifier>
#include <QMessageBox>
#include <QSlider>
#include <QComboBox>
#include <QPushButton>
#include <QCheckBox>
#include <QColor>
#include <QUdpSocket>

#include <stdint.h>
#include <stdarg.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <fcntl.h>
#include <errno.h>
#ifndef __WIN32__
#include <termios.h>
#endif

#include "helpdia.h"
#include "logo.h"

extern const char *vagrearg_logo_563x160_transparent_xpm[];

static const char helpstr[] =
	"<h1>FlipDemo</h1>\n"
	"Flipping dots on battery power or USB controlled flip-fun.\n"
	"<h3>Serial port selection</h3>\n"
	"A drop-down list of system available serial ports is shown and updated "
	"every few seconds. Choose the COMx port (Windows) or ttyACMx port "
	"(Linux) which represents the FlipDemo module. If unsure which port to "
	"choose you can unplug/plug the USB connector to see which port pops up.\n"
	"Windows driver download: <a href=\"http://ww1.microchip.com/downloads/en/DeviceDoc/MCP2200%20Windows%20Driver%202013-02-21.zip\">Microchip MCP2200</a>.\n"
	"<h3>Flipping Dots</h3>\n"
	"You can flip any dots once the FlipDemo module is attached and the serial "
	"port is selected by (left-)clicking the mouse on any of the seven "
	"graphically represented flipdots.\n"
	"<h3>Automatic flipping</h3>\n"
	"You can load a file which holds flip commands by pressing the \"Load Flip-file\" "
	"button and selecting the appropriate file. You can activate flipping, once you "
	"have selected a file, by pressing the \"Start Flip-file\" button.\n"
	"<h3>Flip-file format</h3>\n"
	"The flip-file is a simple text file containing the following character commands:"
	"<table border=\"0\" cellspacing=\"2\" cellpadding=\"1\">\n"
	"<tr><td>a-g</td><td>Flip dots 0-6 to black</td></tr>\n"
	"<tr><td>A-G</td><td>Flip dots 0-6 to white</td></tr>\n"
	"<tr><td>. or ,</td><td>Delay 25ms</td></tr>\n"
	"<tr><td>q or Q</td><td>Stop program</td></tr>\n"
	"</table>\n"
	"Anything else found in the file is ignored. The program repeats ad infinitum if "
	"no stop command is found. You can load a flip-file at any time.\n"
	"Example: \".Ag.Ba.Cb.Dc.Ed.Fe.Gf\" makes a dot move across the module with small delay "
	"and repeats.\n"
	;

HelpDia::HelpDia()
{
	setMinimumWidth(600);

	/* The close button */
	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));

	/* The helptext */
	QLabel *helptext = new QLabel(helpstr);
	helptext->setWordWrap(true);
	helptext->setOpenExternalLinks(true);
	helptext->setTextFormat(Qt::RichText);
	helptext->setTextInteractionFlags(Qt::TextBrowserInteraction);

	/* Logo and link */
	QLabel *lab = new QLabel("<a href=\"http://www.flipdots.com\">http://www.flipdots.com</a>");
	lab->setOpenExternalLinks(true);
	lab->setTextFormat(Qt::RichText);
	lab->setScaledContents(true);
	logo *lgp = new logo();
	QPixmap pm(vagrearg_logo_563x160_transparent_xpm);
	lgp->setPixmap(pm.scaled(141, 40, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));

	QHBoxLayout *hdr = new QHBoxLayout();
	hdr->addWidget(lgp, 0, Qt::AlignLeft);
	hdr->addWidget(lab, 0, Qt::AlignRight);

	/* All in a layout */
	QVBoxLayout *mainLayout = new QVBoxLayout();
	mainLayout->addLayout(hdr);
	QFrame *f = new QFrame();
	f->setFrameStyle(QFrame::HLine | QFrame::Raised);
	f->setLineWidth(3);
	mainLayout->addWidget(f);
	mainLayout->addWidget(helptext);
	mainLayout->addWidget(buttonBox);
	setLayout(mainLayout);

	setWindowTitle("FlipDemo - Flipdot Control - Help");
}
